ChangeLog
=========

.. _master:

master (unreleased)
-------------------

*New:*
    - GH-179: Change cryptography setup version (thanks João Miguel Neves).
    - GH-170: Add User-Agent customisation on OAuth related requests.
    - GH-168: Deprecate Entrust Certificates for Partners API (thanks Sidney Allen).
    - GH-157: Add PurchaseOrders handling (thanks vadim-pavlov).
    - GH-153: Add TaxComponents handling (thanks Richard Bell).
    - GH-152/GH-150: Improve Xero Exceptions handling (thanks Jarek Glowacki, Craig Handley and Brendan Jurd).
    - GH-151: Add delete method in BaseManager (thanks Craig Handley).

*Bugfix:*
    - GH-173: Send Content-Length as string for working attachment uploads (thanks João Neves).
    - GH-154: Handle wrong date timestamp format received from Xero (thanks Matt Healy).
    - GH-149: Change Tracking Category structure in Invoices API (thanks Jacob Hansson).
    - GH-142: Extend BOOLEAN_FIELDS in BaseManager (thanks Alex Burbidge).
    - GH-138: Indentation fix in BaseManager (thanks Asav Patel).
    - GH-137: Fix incorrect field parsing with filters (thanks Alexander Rakowski).
    - GH-90/GH-91: Pin version of cryptography (thanks Aidan Lister).


.. _v0.8.0:

0.8.0 (2016-03-21)
------------------
To Be Done.
